@@ -1,10 +1,9 @@
 // -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; indent-tabs-mode: nil; -*-
 /* :tabSize=4:indentSize=4:noTabs=false:folding=explicit:collapseFolds=1: */
 //
-// export.h: Rcpp R/C++ interface class library -- 
+// export.h: Rcpp R/C++ interface class library --
 //
 // Copyright (C) 2010 - 2013 Dirk Eddelbuettel and Romain Francois
-// Copyright (C) 2013 Rice University
 //
 // This file is part of Rcpp.
 //
@@ -27,59 +26,57 @@
 namespace Rcpp{
     namespace internal{
 
-    	
+
 		template <typename T>
 		std::wstring as_string_elt__impl( SEXP x, R_len_t i, Rcpp::traits::true_type ){
 			const char* y = char_get_string_elt( x, i ) ;
 			return std::wstring(y, y+strlen(y) ) ;
 		}
-		
+
 		template <typename T>
 		std::string as_string_elt__impl( SEXP x, R_len_t i, Rcpp::traits::false_type ){
 			return char_get_string_elt( x, i ) ;
 		}
-    	
+
 		template <typename T>
-		const std::basic_string< typename Rcpp::traits::char_type<T>::type > 
+		const std::basic_string< typename Rcpp::traits::char_type<T>::type >
 		as_string_elt( SEXP x, R_len_t i ){
 			return as_string_elt__impl<T>( x, i, typename Rcpp::traits::is_wide_string<T>::type() ) ;
 		}
-    	
+
         /* iterating */
-        
+
 		template <typename InputIterator, typename value_type>
 			void export_range__impl( SEXP x, InputIterator first, ::Rcpp::traits::false_type ) {
 			const int RTYPE = ::Rcpp::traits::r_sexptype_traits<value_type>::rtype ;
 			typedef typename ::Rcpp::traits::storage_type<RTYPE>::type STORAGE ;
-			SEXP y = PROTECT( ::Rcpp::r_cast<RTYPE>(x) ) ;
+			Shield<SEXP> y( ::Rcpp::r_cast<RTYPE>(x) ) ;
 			STORAGE* start = ::Rcpp::internal::r_vector_start<RTYPE>(y) ;
 			std::copy( start, start + ::Rf_length(y), first ) ;
-			UNPROTECT(1) ;
 		}
-        
+
 		template <typename InputIterator, typename value_type>
 		void export_range__impl( SEXP x, InputIterator first, ::Rcpp::traits::true_type ) {
 			const int RTYPE = ::Rcpp::traits::r_sexptype_traits<value_type>::rtype ;
 			typedef typename ::Rcpp::traits::storage_type<RTYPE>::type STORAGE ;
-			SEXP y = PROTECT( ::Rcpp::r_cast<RTYPE>(x) ) ;
+			Shield<SEXP> y( ::Rcpp::r_cast<RTYPE>(x) ) ;
 			STORAGE* start = ::Rcpp::internal::r_vector_start<RTYPE>(y) ;
 			std::transform( start, start + ::Rf_length(y) , first, caster<STORAGE,value_type> ) ;
-			UNPROTECT(1) ;
         }
-        
+
         // implemented in meat
         template <typename InputIterator, typename value_type>
         void export_range__dispatch( SEXP x, InputIterator first, ::Rcpp::traits::r_type_generic_tag ) ;
-		
+
         template <typename InputIterator, typename value_type>
         void export_range__dispatch( SEXP x, InputIterator first, ::Rcpp::traits::r_type_primitive_tag ) {
 			export_range__impl<InputIterator,value_type>(
-				x, 
+				x,
 				first,
 				typename ::Rcpp::traits::r_sexptype_needscast<value_type>()
 			);
 		}
-        
+
 		template <typename InputIterator, typename value_type>
 		void export_range__dispatch( SEXP x, InputIterator first, ::Rcpp::traits::r_type_string_tag ) {
 			if( ! ::Rf_isString( x) ) throw ::Rcpp::not_compatible( "expecting a string vector" ) ;
@@ -88,54 +85,52 @@ namespace Rcpp{
 				*first = as_string_elt<typename std::iterator_traits<InputIterator>::value_type> ( x, i ) ;
 			}
 		}
-        
+
 		template <typename InputIterator>
 		void export_range( SEXP x, InputIterator first ) {
-			export_range__dispatch<InputIterator,typename std::iterator_traits<InputIterator>::value_type>( 
-				x, 
-				first, 
-				typename ::Rcpp::traits::r_type_traits<typename std::iterator_traits<InputIterator>::value_type>::r_category() 
+			export_range__dispatch<InputIterator,typename std::iterator_traits<InputIterator>::value_type>(
+				x,
+				first,
+				typename ::Rcpp::traits::r_type_traits<typename std::iterator_traits<InputIterator>::value_type>::r_category()
 			);
 		}
-        
-        
+
+
         /* indexing */
-        
+
 		template <typename T, typename value_type>
 			void export_indexing__impl( SEXP x, T& res, ::Rcpp::traits::false_type ) {
 			const int RTYPE = ::Rcpp::traits::r_sexptype_traits<value_type>::rtype ;
 			typedef typename ::Rcpp::traits::storage_type<RTYPE>::type STORAGE ;
-			SEXP y = PROTECT( ::Rcpp::r_cast<RTYPE>(x) ) ;
+			Shield<SEXP> y( ::Rcpp::r_cast<RTYPE>(x) ) ;
 			STORAGE* start = ::Rcpp::internal::r_vector_start<RTYPE>(y) ;
 			R_len_t size = ::Rf_length(y)  ;
 			for( R_len_t i=0; i<size; i++){
 				res[i] =  start[i] ;
 			}
-			UNPROTECT(1) ; /* y */
 		}
-        
+
 		template <typename T, typename value_type>
 		void export_indexing__impl( SEXP x, T& res, ::Rcpp::traits::true_type ) {
 			const int RTYPE = ::Rcpp::traits::r_sexptype_traits<value_type>::rtype ;
 			typedef typename ::Rcpp::traits::storage_type<RTYPE>::type STORAGE ;
-			SEXP y = PROTECT( ::Rcpp::r_cast<RTYPE>(x) ) ;
+			Shield<SEXP> y( ::Rcpp::r_cast<RTYPE>(x) );
 			STORAGE* start = ::Rcpp::internal::r_vector_start<RTYPE>(y) ;
 			R_len_t size = ::Rf_length(y)  ;
 			for( R_len_t i=0; i<size; i++){
 				res[i] = caster<STORAGE,value_type>(start[i]) ;
 			}
-			UNPROTECT(1) ; /* y */
 		}
 
 		template <typename T, typename value_type>
 		void export_indexing__dispatch( SEXP x, T& res, ::Rcpp::traits::r_type_primitive_tag ) {
 			export_indexing__impl<T,value_type>(
-				x, 
+				x,
 				res,
 				typename ::Rcpp::traits::r_sexptype_needscast<value_type>()
 			);
 		}
-        
+
 		template <typename T, typename value_type>
 		void export_indexing__dispatch( SEXP x, T& res, ::Rcpp::traits::r_type_string_tag ) {
 			if( ! ::Rf_isString( x) ) throw Rcpp::not_compatible( "expecting a string vector" ) ;
@@ -144,16 +139,16 @@ namespace Rcpp{
 				res[i] = as_string_elt< value_type >( x, i) ;
 			}
 		}
-       
+
 		template <typename T, typename value_type>
 		void export_indexing( SEXP x, T& res ) {
-			export_indexing__dispatch<T,value_type>( 
-				x, 
-				res, 
-				typename ::Rcpp::traits::r_type_traits<value_type>::r_category() 
+			export_indexing__dispatch<T,value_type>(
+				x,
+				res,
+				typename ::Rcpp::traits::r_type_traits<value_type>::r_category()
 			);
 		}
-        
+
     }
 }
 
